<?xml version="1.0" ?><!DOCTYPE TS><TS language="id" version="2.1">
<context>
    <name>AboutView</name>
    <message>
        <source>There&apos;s life outside the browser!</source>
        <translation>Ada kehidupan diluar browser!</translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation>Versi %1</translation>
    </message>
    <message>
        <source>Licensed to: %1</source>
        <translation>Dilisensikan kepada: %1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 adalah aplikasi gratis, akan tetapi pengembangannya membutuhkan waktu yang cukup berharga.</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation>Silahkan &lt;a href=&apos;%1&apos;&gt;berdonasi&lt;/a&gt; untuk mendukung kelanjutan pangembangan dari %2.</translation>
    </message>
    <message>
        <source>Translate %1 to your native language using %2</source>
        <translation>Terjemahkan %1 ke bahasa aslimu dengan menggunakan %2</translation>
    </message>
    <message>
        <source>Powered by %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open-source software</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Icon designed by %1.</source>
        <translation>Desain ikon oleh %1.</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>Dirilis dibawah the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Tutup</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Tentang</translation>
    </message>
</context>
<context>
    <name>ActivationDialog</name>
    <message>
        <source>Enter your License Details</source>
        <translation>Masukkan detail lisensi Anda</translation>
    </message>
    <message>
        <source>&amp;Email:</source>
        <translation>&amp;Email:</translation>
    </message>
    <message>
        <source>&amp;Code:</source>
        <translation>&amp;Code:</translation>
    </message>
</context>
<context>
    <name>ActivationView</name>
    <message>
        <source>Please license %1</source>
        <translation>Silahkan lisensi %1</translation>
    </message>
    <message>
        <source>This demo has expired.</source>
        <translation>Demo ini telah Habis.</translation>
    </message>
    <message>
        <source>The full version allows you to watch videos without interruptions.</source>
        <translation>Anda dapat melihat video tanpa gangguan dengan menggunakan versi penuh</translation>
    </message>
    <message>
        <source>Without a license, the application will expire in %1 days.</source>
        <translation>Tanpa lisensi, aplikasi akan kadaluarsa dalam %1 hari.</translation>
    </message>
    <message>
        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
        <translation>Dengan membeli versi penuh, Anda akan mendapatkan dukungan kerjakeras Saya letakkan kedalam keasi %1.</translation>
    </message>
    <message>
        <source>Use Demo</source>
        <translation>Gunakan Demo</translation>
    </message>
    <message>
        <source>Enter License</source>
        <translation>Masukkan Lisensi</translation>
    </message>
    <message>
        <source>Buy License</source>
        <translation>Beli Lisensi</translation>
    </message>
</context>
<context>
    <name>AppWidget</name>
    <message>
        <source>Download</source>
        <translation>Unduh</translation>
    </message>
</context>
<context>
    <name>ChannelAggregator</name>
    <message>
        <source>By %1</source>
        <translation>Oleh %1</translation>
    </message>
    <message numerus="yes">
        <source>You have %n new video(s)</source>
        <translation type="unfinished"><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>ChannelItemDelegate</name>
    <message>
        <source>All Videos</source>
        <translation>Semua video</translation>
    </message>
    <message>
        <source>Unwatched Videos</source>
        <translation>Video belum dilihat</translation>
    </message>
</context>
<context>
    <name>ChannelView</name>
    <message>
        <source>Name</source>
        <translation>Nama</translation>
    </message>
    <message>
        <source>Last Updated</source>
        <translation>Diperbarui terakhir kali</translation>
    </message>
    <message>
        <source>Last Added</source>
        <translation>Ditambahkan terakhir kali</translation>
    </message>
    <message>
        <source>Last Watched</source>
        <translation>Dilihat terakhir kali</translation>
    </message>
    <message>
        <source>Most Watched</source>
        <translation>Paling sering dilihat</translation>
    </message>
    <message>
        <source>Sort by</source>
        <translation>Urutkan berdasar</translation>
    </message>
    <message>
        <source>Mark all as watched</source>
        <translation>Tandai sudah dilihat</translation>
    </message>
    <message>
        <source>Show Updated</source>
        <translation>Acara Terbarui</translation>
    </message>
    <message>
        <source>You have no subscriptions. Use the star symbol to subscribe to channels.</source>
        <translation>Anda tidak punya langganan. Gunakan simbol bintang untuk berlangganan ke saluran.</translation>
    </message>
    <message>
        <source>All Videos</source>
        <translation>Semua video</translation>
    </message>
    <message>
        <source>Unwatched Videos</source>
        <translation>Video belum dilihat</translation>
    </message>
    <message>
        <source>Mark as Watched</source>
        <translation>Tandai sudah dilihat</translation>
    </message>
    <message>
        <source>Unsubscribe</source>
        <translation>Berhenti berlangganan</translation>
    </message>
    <message>
        <source>There are no updated subscriptions at this time.</source>
        <translation>Tidak ada langganan yang diperbarui saat ini</translation>
    </message>
</context>
<context>
    <name>DataUtils</name>
    <message>
        <source>Just now</source>
        <translation>Baru saja</translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n month(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform></translation>
    </message>
    <message>
        <source>K</source>
        <comment>K as in Kilo, i.e. thousands</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>M</source>
        <comment>M stands for Millions</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>B</source>
        <comment>B stands for Billions</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 views</source>
        <translation>%1 tampilan</translation>
    </message>
    <message numerus="yes">
        <source>%n week(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <source>bytes</source>
        <translation>bit</translation>
    </message>
    <message>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <source>MB</source>
        <translation>MB</translation>
    </message>
    <message>
        <source>bytes/sec</source>
        <translation>bit/dtk</translation>
    </message>
    <message>
        <source>KB/sec</source>
        <translation>KB/detik</translation>
    </message>
    <message>
        <source>MB/sec</source>
        <translation>MB/sec</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>detik</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>menit</translation>
    </message>
    <message>
        <source>%4 %5 remaining</source>
        <translation>%4 %5 sisanya</translation>
    </message>
</context>
<context>
    <name>DownloadManager</name>
    <message>
        <source>%1 downloaded in %2</source>
        <translation>%1 diunduh dalam %2</translation>
    </message>
    <message>
        <source>Download finished</source>
        <translation>Unduhan selesai</translation>
    </message>
    <message numerus="yes">
        <source>%n Download(s)</source>
        <translation type="unfinished"><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>DownloadSettings</name>
    <message>
        <source>Change location...</source>
        <translation>Ganti lokasi...</translation>
    </message>
    <message>
        <source>Choose the download location</source>
        <translation>Pilihlah lokasi unduhan</translation>
    </message>
    <message>
        <source>Download location changed.</source>
        <translation>Merubah lokasi unduhan.</translation>
    </message>
    <message>
        <source>Current downloads will still go in the previous location.</source>
        <translation>Unduhan saat ini masih ingin pergi di lokasi sebelumnya.</translation>
    </message>
    <message>
        <source>Downloading to: %1</source>
        <translation>Unduhan ke: %1</translation>
    </message>
</context>
<context>
    <name>DownloadView</name>
    <message>
        <source>Downloads</source>
        <translation>Unduhan</translation>
    </message>
</context>
<context>
    <name>Extra</name>
    <message>
        <source>The executable file has been tempered with, maybe by a virus.</source>
        <translation>arsip exe telah dimodifikasi, mungkin oleh virus</translation>
    </message>
    <message>
        <source>%1 will not run. Try installing again.</source>
        <translation>%1 tidak akan berjalan. Coba instal ulang</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Keluar</translation>
    </message>
    <message>
        <source>Reinstall</source>
        <translation>Instal ulang</translation>
    </message>
</context>
<context>
    <name>GlobalShortcuts</name>
    <message>
        <source>Play</source>
        <translation>Play</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pause</translation>
    </message>
    <message>
        <source>Play/Pause</source>
        <translation>Mainkan/Jeda</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Stop playing after current track</source>
        <translation>Stop playing after current track</translation>
    </message>
    <message>
        <source>Next track</source>
        <translation>Next track</translation>
    </message>
    <message>
        <source>Previous track</source>
        <translation>Previous track</translation>
    </message>
    <message>
        <source>Increase volume</source>
        <translation>Increase volume</translation>
    </message>
    <message>
        <source>Decrease volume</source>
        <translation>Decrease volume</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Mute</translation>
    </message>
    <message>
        <source>Seek forward</source>
        <translation>Seek forward</translation>
    </message>
    <message>
        <source>Seek backward</source>
        <translation>Seek backward</translation>
    </message>
</context>
<context>
    <name>HomeView</name>
    <message>
        <source>Search</source>
        <translation>Search</translation>
    </message>
    <message>
        <source>Find videos and channels by keyword</source>
        <translation>Cari video dan saluran berdasar kata kunci</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Ramban</translation>
    </message>
    <message>
        <source>Browse videos by category</source>
        <translation>Ramban video berdasar kategori</translation>
    </message>
    <message>
        <source>Subscriptions</source>
        <translation>Langganan</translation>
    </message>
    <message>
        <source>Channel subscriptions</source>
        <translation>Saluran langganan</translation>
    </message>
    <message>
        <source>Make yourself comfortable</source>
        <translation>Buat senyaman mungkin</translation>
    </message>
</context>
<context>
    <name>LoadingWidget</name>
    <message>
        <source>Error</source>
        <translation>Gangguan</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Jendela</translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation>&amp;Minimkan</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>&amp;Stop</translation>
    </message>
    <message>
        <source>Stop playback and go back to the search view</source>
        <translation>Stop playback and go back to the search view</translation>
    </message>
    <message>
        <source>P&amp;revious</source>
        <translation>S&amp;ebelumnya</translation>
    </message>
    <message>
        <source>Go back to the previous track</source>
        <translation>Kembali lagi ke trek sebelumnya</translation>
    </message>
    <message>
        <source>S&amp;kip</source>
        <translation>S&amp;kip</translation>
    </message>
    <message>
        <source>Skip to the next video</source>
        <translation>Skip to the next video</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>&amp;Play</translation>
    </message>
    <message>
        <source>Resume playback</source>
        <translation>Resume playback</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>&amp;Full Screen</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>Go full screen</translation>
    </message>
    <message>
        <source>&amp;Compact Mode</source>
        <translation>&amp;Model kompak</translation>
    </message>
    <message>
        <source>Hide the playlist and the toolbar</source>
        <translation>Hide the playlist and the toolbar</translation>
    </message>
    <message>
        <source>Open the &amp;YouTube Page</source>
        <translation>Buka &amp;Halaman YouTube</translation>
    </message>
    <message>
        <source>Go to the YouTube video page and pause playback</source>
        <translation>Pergi ke halaman video YouTube dan jeda pemutaran</translation>
    </message>
    <message>
        <source>Copy the YouTube &amp;Link</source>
        <translation>Salin YouTube &amp;Pintasan</translation>
    </message>
    <message>
        <source>Copy the current video YouTube link to the clipboard</source>
        <translation>Copy the current video YouTube link to the clipboard</translation>
    </message>
    <message>
        <source>Copy the Video Stream &amp;URL</source>
        <translation>Salin &amp;URL Stream video</translation>
    </message>
    <message>
        <source>Copy the current video stream URL to the clipboard</source>
        <translation>Copy the current video stream URL to the clipboard</translation>
    </message>
    <message>
        <source>Find Video &amp;Parts</source>
        <translation>Mencari Video &amp;Perkakas</translation>
    </message>
    <message>
        <source>Find other video parts hopefully in the right order</source>
        <translation>Mencari bagian-bagian video yang lainnya diharapkan dalam pesanan yang benar</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Remove</translation>
    </message>
    <message>
        <source>Remove the selected videos from the playlist</source>
        <translation>Remove the selected videos from the playlist</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>Move &amp;Up</translation>
    </message>
    <message>
        <source>Move up the selected videos in the playlist</source>
        <translation>Gerakkan ke atas video yang dipilih dalam daftar-main</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>Move &amp;Down</translation>
    </message>
    <message>
        <source>Move down the selected videos in the playlist</source>
        <translation>Gerakkan ke bawah video yang dipilih dalam daftar-main</translation>
    </message>
    <message>
        <source>&amp;Clear Recent Searches</source>
        <translation>&amp;Bersihkan Jejak Pencarian</translation>
    </message>
    <message>
        <source>Clear the search history. Cannot be undone.</source>
        <translation>Menghapus sejarah pencarian. Tidak bisa dikembalikan.</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Cabut</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>Selamat tinggal</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>&amp;Situs web</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>%1 pada Web</translation>
    </message>
    <message>
        <source>Make a &amp;Donation</source>
        <translation>Buat &amp;Sumbangan</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>Please support the continued development of %1</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Tentang</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>Info Tentang %1</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Search</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>Bisukan volume</translation>
    </message>
    <message>
        <source>&amp;Manually Start Playing</source>
        <translation>&amp;Mulai Memainkan secara Manual</translation>
    </message>
    <message>
        <source>Manually start playing videos</source>
        <translation>Mulai memainkan video secara manual</translation>
    </message>
    <message>
        <source>&amp;Downloads</source>
        <translation>&amp;Unduhan-unduhan</translation>
    </message>
    <message>
        <source>Show details about video downloads</source>
        <translation>Tampilkan detail tentang unduhan-unduhan video</translation>
    </message>
    <message>
        <source>&amp;Download</source>
        <translation>&amp;Unduhan</translation>
    </message>
    <message>
        <source>Download the current video</source>
        <translation>Unduhan-unduhan video saat ini</translation>
    </message>
    <message>
        <source>Take &amp;Snapshot</source>
        <translation>Ambil Tangkapan Layar</translation>
    </message>
    <message>
        <source>&amp;Subscribe to Channel</source>
        <translation>&amp;Berlangganan ke Saluran</translation>
    </message>
    <message>
        <source>Share the current video using %1</source>
        <translation>Berbagi video saat ini gunakan %1</translation>
    </message>
    <message>
        <source>&amp;Email</source>
        <translation>&amp;Surat</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>Surat</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Tutup</translation>
    </message>
    <message>
        <source>&amp;Float on Top</source>
        <translation>&amp;Mengambang ke puncak</translation>
    </message>
    <message>
        <source>&amp;Stop After This Video</source>
        <translation>&amp;berhenti setelah video ini</translation>
    </message>
    <message>
        <source>&amp;Report an Issue...</source>
        <translation>&amp;Laporkan masalah...</translation>
    </message>
    <message>
        <source>&amp;Refine Search...</source>
        <translation>&amp;Perbaiki pencarian...</translation>
    </message>
    <message>
        <source>More...</source>
        <translation>Lebih lanjut...</translation>
    </message>
    <message>
        <source>&amp;Related Videos</source>
        <translation>&amp;Video berhubungan</translation>
    </message>
    <message>
        <source>Watch videos related to the current one</source>
        <translation>Lihat video berkaitan dengan yang sekarang</translation>
    </message>
    <message>
        <source>Open in &amp;Browser...</source>
        <translation>Buka di &amp;Peramban</translation>
    </message>
    <message>
        <source>Restricted Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Hide videos that may contain inappropriate content</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Toggle &amp;Menu Bar</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Menu</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Love %1? Rate it!</source>
        <translation>&amp;Love %1? Beri Nilai!</translation>
    </message>
    <message>
        <source>Buy %1...</source>
        <translation>Beli %1...</translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation>&amp;Application</translation>
    </message>
    <message>
        <source>&amp;Playback</source>
        <translation>&amp;Putarbalik</translation>
    </message>
    <message>
        <source>&amp;Playlist</source>
        <translation>&amp;Daftar-Main</translation>
    </message>
    <message>
        <source>&amp;Video</source>
        <translation>&amp;Video</translation>
    </message>
    <message>
        <source>&amp;Share</source>
        <translation>&amp;Berbagi</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Tampak</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Help</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>Tekan %1 untuk menambahkan volume, %2 untuk merendahkan itu</translation>
    </message>
    <message>
        <source>Choose your content location</source>
        <translation>Pilih lokasi konten</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Membuka %1</translation>
    </message>
    <message>
        <source>Do you want to exit %1 with a download in progress?</source>
        <translation>Do you want to exit %1 with a download in progress?</translation>
    </message>
    <message>
        <source>If you close %1 now, this download will be cancelled.</source>
        <translation>Jika Anda menutup %1 sekarang, unduhan ini akan dibatalkan.</translation>
    </message>
    <message>
        <source>Close and cancel download</source>
        <translation>Tutup dan membatalkan unduhan</translation>
    </message>
    <message>
        <source>Wait for download to finish</source>
        <translation>Menunggu unduhannya selesai</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Error: %1</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pause</translation>
    </message>
    <message>
        <source>Pause playback</source>
        <translation>Pause playback</translation>
    </message>
    <message>
        <source>&amp;Loading...</source>
        <translation>&amp;Memuat...</translation>
    </message>
    <message>
        <source>Leave &amp;Full Screen</source>
        <translation>Tinggalkan &amp;Layar Penuh</translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>Sisanya waktu: %1</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>Volume at %1%</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>Volumenya adalah bisu</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>Volumenya tidak bisu</translation>
    </message>
    <message>
        <source>Maximum video definition set to %1</source>
        <translation>Maksimumnya definisi video set ke %1</translation>
    </message>
    <message>
        <source>Your privacy is now safe</source>
        <translation>Privasimu adalah aman sekarang</translation>
    </message>
    <message>
        <source>Downloads complete</source>
        <translation>Unduhan-unduhan komplit</translation>
    </message>
    <message>
        <source>%1 version %2 is now available.</source>
        <translation>%1 versi %2 sekarang telah tersedia.</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Beritahu saya lagi nanti</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Pembaruan data</translation>
    </message>
    <message>
        <source>You can still access the menu bar by pressing the ALT key</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>You can now paste the YouTube link into another application</source>
        <translation>Sekarang Anda dapat paste link YouTube ke dalam aplikasi yang lain</translation>
    </message>
    <message>
        <source>You can now paste the video stream URL into another application</source>
        <translation>You can now paste the video stream URL into another application</translation>
    </message>
    <message>
        <source>The link will be valid only for a limited time.</source>
        <translation>Link akan berlaku hanya untuk waktu yang terbatas.</translation>
    </message>
    <message>
        <source>Downloading %1</source>
        <translation>Downloading %1</translation>
    </message>
    <message>
        <source>of</source>
        <comment>Used in video parts, as in '2 of 3'</comment>
        <translation>dari</translation>
    </message>
    <message>
        <source>part</source>
        <comment>This is for video parts, as in 'Cool video - part 1'</comment>
        <translation>bagian</translation>
    </message>
    <message>
        <source>episode</source>
        <comment>This is for video parts, as in 'Cool series - episode 1'</comment>
        <translation>babak bagian</translation>
    </message>
    <message>
        <source>Sent from %1</source>
        <translation>Dikirim dari %1</translation>
    </message>
    <message>
        <source>Unsubscribe from %1</source>
        <translation>Berhenti berlangganan dari %1</translation>
    </message>
    <message>
        <source>Subscribe to %1</source>
        <translation>Berlangganan ke %1</translation>
    </message>
    <message>
        <source>Switched to %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unsubscribed from %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Subscribed to %1</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MessageWidget</name>
    <message>
        <source>A new version of %1 is available!</source>
        <translation>Versi baru dari %1 tersedia</translation>
    </message>
    <message>
        <source>%1 %2 is now available. You have %3.</source>
        <translation>%1 %2 tersedia. Kamu punya %3</translation>
    </message>
    <message>
        <source>Would you like to download it now?</source>
        <translation>Apakah kamu ingin mengunduhnya sekarang?</translation>
    </message>
    <message>
        <source>Skip This Version</source>
        <translation>Lewati versi ini</translation>
    </message>
    <message>
        <source>Remind Me Later</source>
        <translation>Ingatkan nanti</translation>
    </message>
    <message>
        <source>Install Update</source>
        <translation>Install pembaruan</translation>
    </message>
</context>
<context>
    <name>PasteLineEdit</name>
    <message>
        <source>Paste</source>
        <translation>Tempel</translation>
    </message>
</context>
<context>
    <name>PickMessage</name>
    <message>
        <source>Pick a video</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PlaylistItemDelegate</name>
    <message>
        <source>%1 of %2 (%3) — %4</source>
        <translation>%1 dari %2 (%3) --- %4</translation>
    </message>
    <message>
        <source>Preparing</source>
        <translation>Mempersiapkan</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Gagal</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>Selesai</translation>
    </message>
    <message>
        <source>Stopped</source>
        <translation>Berhenti</translation>
    </message>
    <message>
        <source>Stop downloading</source>
        <translation>Berhenti mengunduh</translation>
    </message>
    <message>
        <source>Show in %1</source>
        <translation>Perlihatkan pada %1</translation>
    </message>
    <message>
        <source>Open parent folder</source>
        <translation>Buka folder utama</translation>
    </message>
    <message>
        <source>Restart downloading</source>
        <translation>Mulai ulang pengunduhan</translation>
    </message>
</context>
<context>
    <name>PlaylistModel</name>
    <message>
        <source>Show %1 More</source>
        <translation>Tampilkan lebih banyak %1</translation>
    </message>
    <message>
        <source>No videos</source>
        <translation>Bukan video</translation>
    </message>
    <message>
        <source>No more videos</source>
        <translation>Tidak ada videos lagi</translation>
    </message>
</context>
<context>
    <name>RefineSearchWidget</name>
    <message>
        <source>Sort by</source>
        <translation>Urutkan berdasar</translation>
    </message>
    <message>
        <source>Relevance</source>
        <translation>Relevansi</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Tanggal</translation>
    </message>
    <message>
        <source>View Count</source>
        <translation>Jumlah tayang</translation>
    </message>
    <message>
        <source>Rating</source>
        <translation>Rating</translation>
    </message>
    <message>
        <source>Anytime</source>
        <translation>Kapanpun</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Hari ini</translation>
    </message>
    <message>
        <source>7 Days</source>
        <translation>7 Hari</translation>
    </message>
    <message>
        <source>30 Days</source>
        <translation>30 Hari</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Durasi</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Semua</translation>
    </message>
    <message>
        <source>Short</source>
        <translation>Pendek</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Sedang</translation>
    </message>
    <message>
        <source>Long</source>
        <translation>Panjang</translation>
    </message>
    <message>
        <source>Less than 4 minutes</source>
        <translation>Kurang dari 4 menit</translation>
    </message>
    <message>
        <source>Between 4 and 20 minutes</source>
        <translation>Antara 4 sampai 20 menit</translation>
    </message>
    <message>
        <source>Longer than 20 minutes</source>
        <translation>Lebih dari 20 menit</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Kualitas</translation>
    </message>
    <message>
        <source>High Definition</source>
        <translation>HD</translation>
    </message>
    <message>
        <source>720p or higher</source>
        <translation>720p atau lebih</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Selesai</translation>
    </message>
</context>
<context>
    <name>RegionsView</name>
    <message>
        <source>Done</source>
        <translation>Selesai</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Search</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>Selamat datang ke &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
    </message>
    <message>
        <source>to start watching videos.</source>
        <translation>to start watching videos.</translation>
    </message>
    <message>
        <source>a keyword</source>
        <translation>sebuah kata kunci</translation>
    </message>
    <message>
        <source>Enter</source>
        <translation>Masukkan</translation>
    </message>
    <message>
        <source>Recent keywords</source>
        <translation>Recent keywords</translation>
    </message>
    <message>
        <source>Recent channels</source>
        <translation>Saluran-saluran saat ini</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Get the full version</translation>
    </message>
</context>
<context>
    <name>SidebarHeader</name>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Kembali</translation>
    </message>
    <message>
        <source>&amp;Forward</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Forward to %1</source>
        <translation>Maju sampai %1</translation>
    </message>
    <message>
        <source>Back to %1</source>
        <translation>Kembali ke %1</translation>
    </message>
</context>
<context>
    <name>SidebarWidget</name>
    <message>
        <source>Refine Search</source>
        <translation>Perbarui pencarian</translation>
    </message>
    <message>
        <source>Did you mean: %1</source>
        <translation>Apakah maksud kamu: %1</translation>
    </message>
</context>
<context>
    <name>SnapshotSettings</name>
    <message>
        <source>Change location...</source>
        <translation>Ganti lokasi...</translation>
    </message>
    <message>
        <source>Snapshot saved to %1</source>
        <translation>Tangkapan Layar disimpan sebagai %1</translation>
    </message>
    <message>
        <source>Snapshots location changed.</source>
        <translation>Lokasi tangkapan layar diubah</translation>
    </message>
</context>
<context>
    <name>StandardFeedsView</name>
    <message>
        <source>Most Popular</source>
        <translation>Paling populer</translation>
    </message>
</context>
<context>
    <name>UpdateDialog</name>
    <message>
        <source>Downloading update...</source>
        <translation>Mengunduh pembaruan...</translation>
    </message>
    <message>
        <source>Downloading %1...</source>
        <translation>Mengunduh %1...</translation>
    </message>
</context>
<context>
    <name>YTRegions</name>
    <message>
        <source>Algeria</source>
        <translation>Algeria</translation>
    </message>
    <message>
        <source>Argentina</source>
        <translation>Argentina</translation>
    </message>
    <message>
        <source>Australia</source>
        <translation>Australia</translation>
    </message>
    <message>
        <source>Belgium</source>
        <translation>Belgia</translation>
    </message>
    <message>
        <source>Brazil</source>
        <translation>Brazil</translation>
    </message>
    <message>
        <source>Canada</source>
        <translation>Kanada</translation>
    </message>
    <message>
        <source>Chile</source>
        <translation>Chile</translation>
    </message>
    <message>
        <source>Colombia</source>
        <translation>Kolombia</translation>
    </message>
    <message>
        <source>Czech Republic</source>
        <translation>Republik Chechnya</translation>
    </message>
    <message>
        <source>Egypt</source>
        <translation>Mesir</translation>
    </message>
    <message>
        <source>France</source>
        <translation>Prancis</translation>
    </message>
    <message>
        <source>Germany</source>
        <translation>Jerman</translation>
    </message>
    <message>
        <source>Ghana</source>
        <translation>Ghana</translation>
    </message>
    <message>
        <source>Greece</source>
        <translation>Yunani</translation>
    </message>
    <message>
        <source>Hong Kong</source>
        <translation>Hongkong</translation>
    </message>
    <message>
        <source>Hungary</source>
        <translation>Hungaria</translation>
    </message>
    <message>
        <source>India</source>
        <translation>India</translation>
    </message>
    <message>
        <source>Indonesia</source>
        <translation>Indonesia</translation>
    </message>
    <message>
        <source>Ireland</source>
        <translation>Irlandia</translation>
    </message>
    <message>
        <source>Israel</source>
        <translation>Israel</translation>
    </message>
    <message>
        <source>Italy</source>
        <translation>Italia</translation>
    </message>
    <message>
        <source>Japan</source>
        <translation>Jepang</translation>
    </message>
    <message>
        <source>Jordan</source>
        <translation>Yordania</translation>
    </message>
    <message>
        <source>Kenya</source>
        <translation>Kenya</translation>
    </message>
    <message>
        <source>Malaysia</source>
        <translation>Malaysia</translation>
    </message>
    <message>
        <source>Mexico</source>
        <translation>Meksiko</translation>
    </message>
    <message>
        <source>Morocco</source>
        <translation>Maroko</translation>
    </message>
    <message>
        <source>Netherlands</source>
        <translation>Belanda</translation>
    </message>
    <message>
        <source>New Zealand</source>
        <translation>Selandia Baru</translation>
    </message>
    <message>
        <source>Nigeria</source>
        <translation>Nigeria</translation>
    </message>
    <message>
        <source>Peru</source>
        <translation>Peru</translation>
    </message>
    <message>
        <source>Philippines</source>
        <translation>Filipina</translation>
    </message>
    <message>
        <source>Poland</source>
        <translation>Polandia</translation>
    </message>
    <message>
        <source>Russia</source>
        <translation>Rusia</translation>
    </message>
    <message>
        <source>Saudi Arabia</source>
        <translation>Arab Saudi</translation>
    </message>
    <message>
        <source>Singapore</source>
        <translation>Singapura</translation>
    </message>
    <message>
        <source>South Africa</source>
        <translation>Afrika Selatan</translation>
    </message>
    <message>
        <source>South Korea</source>
        <translation>Korea Selatan</translation>
    </message>
    <message>
        <source>Spain</source>
        <translation>Spanyol</translation>
    </message>
    <message>
        <source>Sweden</source>
        <translation>Swedia</translation>
    </message>
    <message>
        <source>Taiwan</source>
        <translation>Taiwan</translation>
    </message>
    <message>
        <source>Tunisia</source>
        <translation>Tunisia</translation>
    </message>
    <message>
        <source>Turkey</source>
        <translation>Turki</translation>
    </message>
    <message>
        <source>Uganda</source>
        <translation>Uganda</translation>
    </message>
    <message>
        <source>United Arab Emirates</source>
        <translation>Uni Emirat Arab</translation>
    </message>
    <message>
        <source>United Kingdom</source>
        <translation>Inggris</translation>
    </message>
    <message>
        <source>Yemen</source>
        <translation>Yaman</translation>
    </message>
    <message>
        <source>Worldwide</source>
        <translation>Dunia</translation>
    </message>
</context>
<context>
    <name>YTVideo</name>
    <message>
        <source>Cannot get video stream for %1</source>
        <translation>Tidak bisa mendapatkan video stream untuk %1</translation>
    </message>
</context>
</TS>